@@ -548,13 +548,14 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 		{
 		chum_set_duetto(FALSE);
 		}
-	gchar *new_name;
-	new_name =  g_strdup_printf("_%s", name);
-	handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), (gpointer)new_name);
-	g_free(new_name);
+	gchar *name_for_mentor;
+	name_for_mentor =  g_strdup_printf("_%s", name);
+	handler_for_mentor_say_selected=g_signal_connect_data(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected),
+                                                                  (gpointer)name_for_mentor, (GClosureNotify) g_free,0);
 	
 	ClutterActor* button;
 	ClutterActor* texture;
+	gchar *new_name;
 	new_name = g_strdup_printf("songselection-%s-icon-texture",name);
 
 	button = jammo_get_actor_by_id("songselection-duetto");
