@@ -6,7 +6,7 @@ License: GPLv2, read more from COPYING
 #define __JAMMO_TEXTURE_H__
 
 #include <clutter/clutter.h>
-#include "../meam/sequencer/sample.h"
+#include "../meam/jammo-sample.h"
 
 #define JAMMO_TYPE_TEXTURE (jammo_texture_get_type ())
 #define JAMMO_TEXTURE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), JAMMO_TYPE_TEXTURE, JammoTexture))
@@ -28,12 +28,13 @@ typedef struct _JammoTextureClass
 	ClutterTextureClass parent_class;
 } JammoTextureClass;
 
+GType jammo_texture_get_type(void);
 
 JammoTexture* jammo_texture_new();
 void jammo_texture_set_sound_file_name(JammoTexture* texture, const gchar* sound_file);
 const gchar* jammo_texture_get_sound_file_name(JammoTexture* texture);
 
-void jammo_texture_set_sample(JammoTexture* texture, Sample* sound_file);
-Sample* jammo_texture_get_sample(JammoTexture* texture);
+void jammo_texture_set_sample(JammoTexture* texture, JammoSample* sample);
+JammoSample* jammo_texture_get_sample(JammoTexture* texture);
 
 #endif /* __JAMMO_TEXTURE_H__ */
